@@ -601,8 +601,7 @@ class BaseExperiment:
         log_dir = f"{folder_dir}/version_{version}"
         self._create_folder(log_dir)
         self.logger = SummaryWriter(log_dir=log_dir)
-        if sample_weight is None:
-            sample_weight = np.ones_like(self.y_train)
+        
         self.model.fit(self.X_train, self.y_train, sample_weight)
         y_train_preds = self.model.predict(self.X_train)
         train_acc = (self.y_train==y_train_preds).astype(float).mean()
